#
# spec file for package python-pyface
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-pyface
Version:        8.0.0
Release:        5.1
Summary:        Traits-capable windowing framework
# Source code is under BSD but images are under different licenses
# and details are inside image_LICENSE.txt
License:        BSD-3-Clause AND EPL-1.0 AND LGPL-2.1-only AND LGPL-3.0-only AND SUSE-Public-Domain
URL:            https://github.com/enthought/pyface
Source:         https://files.pythonhosted.org/packages/source/p/pyface/pyface-%{version}.tar.gz
# PATCH-FIX-OPENSUSE fix-wx-tests.patch
Patch0:         fix-wx-tests.patch
# PATCH-FIX-UPSTREAM skip-qt4-tests.patch gh#enthought/pyface#1252 mcepl@suse.com
Patch1:         skip-qt4-tests.patch
# gh#enthought/pyface#1255, might be pulled in by wxPython
# BuildRequires:  %%{python_module Pillow}
#!BuildIgnore:  python39-Pillow
#!BuildIgnore:  python310-Pillow
#!BuildIgnore:  python311-Pillow
#!BuildIgnore:  python312-Pillow
#!BuildIgnore:  python313-Pillow
BuildRequires:  %{python_module Pygments}
BuildRequires:  %{python_module importlib-metadata if %python-base < 3.10}
BuildRequires:  %{python_module importlib-resources >= 1.1.0 if %python-base < 3.9}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module qt5}
BuildRequires:  %{python_module qtwebengine-qt5}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module traits >= 6.2}
BuildRequires:  %{python_module wheel}
BuildRequires:  %{python_module wxWidgets}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  xvfb-run
BuildRequires:  %{python_module numpy if (%python-base without python36-base)}
%if %{python_version_nodots} < 310
Requires:       python-importlib-metadata
%endif
%if %{python_version_nodots} < 39
Requires:       python-importlib-resources >= 1.1.0
%endif
Requires:       python-traits >= 6.2
Recommends:     python-Pygments
Recommends:     python-numpy
Recommends:     python-qt5
Recommends:     python-qtwebengine-qt5
Recommends:     python-traitsui
Recommends:     python-wxWidgets
BuildArch:      noarch

%python_subpackages

%description
The pyface project contains a toolkit-independent GUI abstraction layer,
which is used to support the "visualization" features of the Traits package.
Thus, you can write code in terms of the Traits API (views, items, editors,
etc.), and let pyface and your selected toolkit and back-end take care of
the details of displaying them.

Part of the Enthought Tool Suite (ETS).

%prep
%autosetup -p1 -n pyface-%{version}

# Fix executable bits
find . -name \*.py -exec chmod -x '{}' \;

%build
%pyproject_wheel

%install
%pyproject_install
%{python_expand %fdupes %{buildroot}%{$python_sitelib}
$python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/pyface/sizers
$python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/pyface/sizers
%fdupes %{buildroot}%{$python_sitelib}/pyface/sizers
}

%check
export ETS_TOOLKIT=qt
%{python_expand mkdir tester_%{$python_bin_suffix}
pushd tester_%{$python_bin_suffix}
cp -a %{buildroot}%{$python_sitelib} python_sitelib # copy to avoid modification of original https://github.com/enthought/pyface/issues/1254
export PYTHONPATH=`pwd`/python_sitelib
xvfb-run --server-args "-screen 0 1920x1080x24" $python -m unittest discover -v pyface
rm -rf python_sitelib
popd
# wait 2 seconds before the next xvfb-run
sleep 2
}

%files %{python_files}
%doc README.rst
%license LICENSE.txt image_LICENSE*.txt
%{python_sitelib}/pyface
%{python_sitelib}/pyface-%{version}*-info

%changelog
* Tue Apr  8 2025 Ben Greiner <code@bnavigator.de>
- Remove dependencies on importlib backports for current python
  versions
* Thu Nov 21 2024 Dirk Müller <dmueller@suse.com>
- buildignore also python313-Pillow
* Fri Feb  9 2024 Ben Greiner <code@bnavigator.de>
- Add missing setuptools build requirement
- Make skip-qt4-tests.patch independent of ETS_TOOLKIT variable
- Make sure we really don't import Pillow for testing
* Thu Dec  7 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Avoid non-deterministic modification of files by tests
- Fix rpmlint warnings: non-executable code should not be marked
  as executable.
* Tue Nov  7 2023 Matej Cepl <mcepl@cepl.eu>
- Update to 8.0.0:
  - This is a major release which removes a number of things
    which have been deprecated for a number of years. The most
    significant change in this release is that the Qt toolkit
    backend has been moved from the pyface.ui.qt4 package to the
  - Additionally this release uses the module-level __getattr__
    system introduced in Python 3.7 to delay imports from
    the api modules which have side-effects, particularly
    toolkit selection. This means that you can, for example,
    import pyface.api and toolkit selection will be deferred
    until you actually request a class or object which is
    toolkit-dependent. Part of this included adding formal
    interfaces for ActionManager and its subclasses
  - adds support for Python 3.11 and drops support for Python 3.6
  - adds support for PySide 6.4+ and the new enum system
  - removes code supporting PyQt4, and supports more modern
    imports from pyface.qt, such as pyface.qt.QtWidgets.
  - removes many things flagged as deprecated in Pyface 7
  - consistently add interface classes to api modules.
  - adds new Field subclasses, including an ImageField and
    LabelField
  - moves to a pyproject.toml-based packaging solution, removing
    setup.py
- Add skip-qt4-tests.patch to overcome gh#enthought/pyface#1252
- Comment out dependency on Pillow to overcome gh#enthought/pyface#1255
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 7.4.4:
  * This is a quick bugfix release that resolves some issues with the 7.4.3
    release on CI for downstream projects.  The issues were on testing code,
    and so shouldn't impact application code or behaviour.
  * Don't raise ConditionTimeoutError if test doesn't time out (#1182)
- update to 7.4.3:
  * Fix code editor gutter widget on recent Python versions (#1176)
  * fix issues with FileDialog and DirectoryDialog close method on Linux
  * update setup.py metadata (#1173)
  * restrict to PySide versions before 6.4.0 (#1169)
  * don't do unneccessary evaluations of conditions in EventLoopHelper
  * fix a deleted object error in PyQt5 (#1161)
  * better reporting of toolkit errors (#1157)
  * fix some Python 2 style print statements in documentation (#1157)
* Thu Sep 22 2022 Daniel Garcia <daniel.garcia@suse.com>
- Removed pyface-pr958-qt5deprecation.patch because it's not needed anymore
  with the new version
- Add fix-wx-tests.patch to be able to run all wx tests
- Update to 7.4.2
  * fixes for Qt workbench backend (#1149)
  * fix ConsoleWidget PySide6 issues (#1146, #1147)
  * fix default AboutDialog image (#1142)
  * remove reference cycle for actions on clean-up (#1143)
  * status bar manager not cleaned up properly (#1141)
  * expose QOpenGLWidget in a consistent place in pyface.qt (#1138)
  * map popup menu coordinates to global (#1137)
  * fix issues with last window close on Qt6 (#1136)
  * font size and stretch are ints at the toolkit level (#1118)
- Release 7.4.1
  * fix segfaults and memory corruption from dropped QImage references (#1108)
- Release 7.4.0
  * adding intermediate interfaces and classes to collect common roles and
  behaviours.
  * adding hooks to control widget sizing behaviour within layouts/sizers.
  deprecating behavior where a class creates the underlying toolkit widget in
  the __init__ method. This was done by a small minority of Widget classes,
  now all widgets are able to use two-step creation (first the
  instance, then the toolkit object via the create() method).
  * creating Qt versions of some widgets, and filling in some gaps in widget
  types (particularly for Fields)
  * providing image classes that wrap PIL images and NumPy arrays that allow
  dynamic images and icons in addition to the resource-based versions.
  * providing a toolkit-independent Font class and corresponding trait that
  supports similar use-cases to the existing TraitsUI Font trait.
  * extracting the menu and toolbar Schema system from Tasks and making it more
  generally useable.
* Wed Jan 12 2022 Ben Greiner <code@bnavigator.de>
- Add pyface-pr958-qt5deprecation.patch for python310 test failures
  * gh#enthought/pyface#958, gh#enthought/pyface#873
  * Remove wx test skip for Python 3.9 because the patch for qt
    weirdly also fixes the previously encountered problems with
    wx in python39 and python310 as well.
* Thu Apr 22 2021 Ben Greiner <code@bnavigator.de>
- test with qtwebengine, now that qtwebkit has been removed.
* Sat Apr 17 2021 Ben Greiner <code@bnavigator.de>
- Exclude wx test for python39 flavor because of segfault inside
  xvfb-run
* Tue Feb 23 2021 Ben Greiner <code@bnavigator.de>
- Update to 7.3.0
  * Replace use of Traits on_trait_change with observe.
- Release 7.2.0
  * New <pyface.undo> subpackage that has been copied over from
    apptools (soon to be deprecated in apptools)
- Release 7.1.0
  * A new pyface.data_view subpackage has been introduced
    to support visualization of hierarchical and
    non-hierarchical tabular data. See Pyface DataViews
    section of the user manual for an introduction.
    Additional examples are also added to the source
    distribution. Please note that as of this release the
    API is provisional.
  * A new pyface.color.Color class and a corresponding
    pyface.ui_traits.PyfaceColor trait type have been
    introduced to support representing colors via a toolkit
    independent API. See Trait Types section of the user manual
    for further details.
- Add explicit skip_python2
- Don't test numpy in python36 (NEP 29, not available in TW)
* Mon Jul 13 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 7.0.0
  * Use Traits 6 features (#480, #494)
  * WxPython 4 support (#469, #473, #497, $499)
  * Remove six and other Python 2 code (#493)
  * Add utility functions for Qt images (#498)
  * Allow live update of Action images (#484)
  * Add Qt Multimedia APIs to pyface.qt (#485)
  * Allow additional copyright notices in the AboutDialog class (#467)
  * Replace default AboutDialog and Splashscreen images with Python logo (#454)
  * Allow etstool.py to run in non EDM environments (#443)
  * Add assertEventuallyTrueInGui method to GuiTestAssistant (#419)
  * Multiple bugfixes
* Tue Jul 23 2019 Todd R <toddrme2178@gmail.com>
- Update to 6.1.2
  + Enhancements
  * Application classes
  * New API for Timers
  * Support simple widgets in toolbars
  * Experimental support of Pyside2
  * Support single codebase for Python 2 and 3
  * Support ui dispatch for Traits even if TraitsUI not available
  + Fixes
  * Remove use of deprecated Traits get() method
  * Fix pyqt5 webkit imports
  * Remove use of cmp in fix_introspection_bug
  * Update CI infrastructure
  * Update unittest imports
  * Fix bug in argspec usage
  * Fix regression in DoLaterTimer API
  * Fix context menu behaviour
  * Remove TraitsUI dependency in GuiTestAssistant
  * Fixes for ProgressDialog
  * Fixes for toolbar and statusbar life cycles
  * Fixes for CI
  * Fix usages of event_loop() in tests
  * Fix SplitEditorAreaPane tab dragging on Qt5
  * Fix resource warnings in test suite from un-closed files
  * Remove uses of deprecated HasTraits.set() method
  * Add Qt5 support for deprecated Qt Style options that Mayavi needs
  * Various fixes around Qt API selection
  * Fixes for setup.py
* Wed Apr 17 2019 Todd R <toddrme2178@gmail.com>
- Use qt5 backend.
* Wed May  9 2018 toddrme2178@gmail.com
- Release 6.0.0
  + Enhancements
  * Tasks support for wxPython (#223, #247)
  * Qt5 Support (#170, #256, #264, #265, #268, #271, #279, #292)
  * Disentangling Pyface and TraitsUI (#221, #250)
  * EDM-based test runner (#243, #296, #298)
  * Improved toolkit selection (#259, #260, #276, #304, #305)
  * Move wxPython-specific code to pyface.wx (#261)
  * Single choice dialog for Qt toolkit (was already in wx toolkit) (#217)
  * Add ‘detail’ and ‘informative’ to window dialog helpers (#181)
  * Code coverage reporting (#214)
  * All Pyface widgets now have visible and enabled traits (#284)
  * Allow “qt” as a synonym for “qt4” (#304)
  * PythonShell widget history exposed via the API (#314)
  * Experimental PySide2 support (#303)
  + Fixes
  * Documentation fixes (#220, #231)
  * Testing and CI fixes (#224, #226, #239, #248, #252, #253, #257, #267, #270, #277, #278, #281, #283)
  * Fix bug updating Tasks window titles (#225)
  * Python 3 compatibility fixes (#228)
  * Remove use of cmp in the AdvancedEditorAreaPane (#237)
  * AutoPEP8 of Pyface codebase (#241)
  * Minor WxPython fixes (#230, #269, #275, #294)
  * Don’t use sendPostedEvents in Qt GUI.do_trait_later (#273)
  * Fix ordering of items when appending to an ActionManager default group (#290)
  * Explicit life-cycle for Qt event filters on Widgets (#300)
  * Fixes to ensure demos and examples work (#308)
- Use license tag
* Wed Aug 23 2017 toddrme2178@gmail.com
- Implement single-spec version
- Release 5.1.0
  + Enhancements
  * Added documentation on toolkit selection (#197)
  * Clarify the purpose of LayoutContainer construction args (#189)
  * Improve ETSConfig toolkit selection (#187)
  + Fixes
  * Fix restoring show_editor_area from saved perspective(#207)
  * Fix WorkbenchWindowLayout in Python 3 (#206)
  * Update SplitEditorAreaPane's active editor when focus changes under Qt (#203, #204)
  * Read-only CodeEditor should not allow adding newlines in View (#200)
  * Fix exception when closing all docks in a workbench window (#199)
  * Fix extended trait change description in qt dock pane (#194)
  * Fix Qt Workbench dock widget control in a workbench window (#192)
  * Fix double UnInit of AUI in ApplicationWindow under Wx (#184, #185)
  * Fix IPythonWidget syntax error (#178, #186)
  * Fix ProgressDialog timer labels #(183)
  * Fix Qt CodeWidget when focus goes out of a widget (#176, #177)
  * Fix Qt and Wx ProgressDialog for updating message (#176, #177)
* Tue Apr 12 2016 toddrme2178@gmail.com
- Relase 5.0.0
  - Features
  * Experimental support for Python 3 (#160, #161, #162, #163).
  * Experimental support for wxPython 3 (#168).
  - Enhancements
  * Make Qt 4 the default GUI toolkit (#172).
  - Fixes
  * Fix issue with reading unicode text from Qt clipboard (#159).
  * Remove usage of `logging.warn` in favour of `logger.warning` (#167).
* Fri Sep  4 2015 toddrme2178@gmail.com
- Release 4.5.2
  - Enhancements
  * Added many tests, increasing test coverage by about 10%% (PR#147)
  * Add continuous integration support for Windows and Qt via Appveyor (PR #154)
  * Use Travis CI's container infrastructure (PR #153)
  - Fixes
  * Stop TaskWindow layout running after window control destroyed (PR#156).
  * Fix file execution for PythonShell on Windows with Qt backend (PR#147).
  * Fix Group objects setting wrong trait when naming new Actions (PR#147).
  * Fix ActionItem change handler for `visible` trait (PR#147).
  * Fix failure to release application window from AUIManager in Wx (PR#147).
  * Fix missing import for qt4 confirmation dialog (PR#147).
  * Deprecate Wx as the default toolkit choice for Pyface (PR#150).
  * Improve error handling in toolkit imports; fix some import errors which
    made the Qt PythonEditor unavailable; and make pygments a formal requirement
    rather than implicit (PR#144).
- Release Release 4.5.1
  - Fixes
  * fix MANIFEST.in (PR#131).
  * Fix incompatibility with Pygments 2.x, which was causing tracebacks
    during syntax highlighting (PR#136).
- Release Release 4.5.0
  - Enhancements
  * Add testing assistants (Qt) (PR#118).
  * Support menus in toolbars (Qt) (PR#104).
  * keybindings update for other editor area classes (PR#103).
  * Change advanced editor area tab switching shortcut to Ctrl+PgUp/Down (PR#99).
  * ToolBar: Listen to Action name changes for toolbar actions (PR#90).
  - Fixes
  * Fix reference to attribute (PR#112).
  * Fixed wx 2.9 incompatibility bug in ProgressDialog (PR#106).
  * Qt CodeEditor pygments monkeypatch conflict with ipython (PR#100).
  * Documentation fix (PR#95).
  * Tooltip for first editor of SplitEditorAreaPane was broken (PR#108)
* Mon Oct 13 2014 toddrme2178@gmail.com
- Update to 4.4.0
  * No upstream changelog
- Updated source to pypi url.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sat Apr 20 2013 toddrme2178@gmail.com
- Added a note about being part of the Enthought Tool Suite (ETS).
* Thu Apr 18 2013 toddrme2178@gmail.com
- Update to 4.3.0
  * no changelog
* Tue May 22 2012 toddrme2178@gmail.com
- Initial spec file
